@@ -13,7 +13,7 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import json
+from oslo_serialization import jsonutils
 
 from mistralclient.api import base as api_base
 from mistralclient.api.v2 import executions
@@ -52,10 +52,23 @@ SUB_WF_EXEC = {
     }
 }
 
+ERROR_SUB_WF_EXEC = {
+    'id': "456",
+    'workflow_id': '123e4567-e89b-12d3-a456-426655440000',
+    'workflow_name': 'my_sub_wf',
+    'workflow_namespace': '',
+    'task_execution_id': "abc",
+    'description': '',
+    'state': 'ERROR',
+    'input': {}
+}
+
+
 SOURCE_EXEC = EXEC
 SOURCE_EXEC['source_execution_id'] = EXEC['workflow_id']
 URL_TEMPLATE = '/executions'
 URL_TEMPLATE_ID = '/executions/%s'
+URL_TEMPLATE_SUB_EXECUTIONS = '/executions/%s/executions%s'
 
 
 class TestExecutionsV2(base.BaseClientV2Test):
@@ -67,7 +80,7 @@ class TestExecutionsV2(base.BaseClientV2Test):
         body = {
             'workflow_name': EXEC['workflow_name'],
             'description': '',
-            'input': json.dumps(EXEC['input'])
+            'input': jsonutils.dumps(EXEC['input'])
         }
 
         ex = self.executions.create(
@@ -93,7 +106,7 @@ class TestExecutionsV2(base.BaseClientV2Test):
         body = {
             'workflow_id': EXEC['workflow_id'],
             'description': '',
-            'input': json.dumps(EXEC['input'])
+            'input': jsonutils.dumps(EXEC['input'])
         }
 
         ex = self.executions.create(
@@ -265,3 +278,35 @@ class TestExecutionsV2(base.BaseClientV2Test):
         self.requests_mock.delete(url, status_code=204)
 
         self.executions.delete(EXEC['id'])
+
+    def test_report(self):
+        url = self.TEST_URL + URL_TEMPLATE_ID % EXEC['id'] + '/report'
+
+        expected_json = {
+            'root_workflow_execution': {},
+            'statistics': {}
+        }
+
+        self.requests_mock.get(url, json=expected_json)
+
+        report = self.executions.get_report(EXEC['id'])
+
+        self.assertDictEqual(expected_json, report)
+
+    def test_get_sub_executions(self):
+        url = self.TEST_URL + URL_TEMPLATE_SUB_EXECUTIONS \
+              % (EXEC['id'], '?max_depth=-1&errors_only=')
+
+        self.requests_mock.get(url, json={'executions': [EXEC, SUB_WF_EXEC]})
+
+        sub_execution_list = self.executions.get_ex_sub_executions(EXEC['id'])
+
+        self.assertEqual(2, len(sub_execution_list))
+        self.assertDictEqual(
+            executions.Execution(self.executions, EXEC).to_dict(),
+            sub_execution_list[0].to_dict()
+        )
+        self.assertDictEqual(
+            executions.Execution(self.executions, SUB_WF_EXEC).to_dict(),
+            sub_execution_list[1].to_dict()
+        )
